@@ -31,17 +31,14 @@
 #include <QDateTime>
 #include <QDebug>
 #include <QVersionNumber>
+#include <QtNetwork>
 #ifndef QT_NO_WIDGETS
 #include <QFileDialog>
 #include <QApplication>
 #endif
 #ifdef Q_OS_DARWIN
-#include <QtNetwork>
 #include <QMessageBox>
 #include <security/security.h>
-#else
-#include "openssl/evp.h"
-#include "openssl/sha.h"
 #endif
 
 #ifdef Q_OS_WIN
@@ -60,6 +57,12 @@
 #include <QtPlatformHeaders/QEglFSFunctions>
 #endif
 
+#ifdef Q_OS_LINUX
+#ifndef QT_NO_DBUS
+#include "linux/networkmanagerapi.h"
+#endif
+#endif
+
 ImageWriter::ImageWriter(QObject *parent)
     : QObject(parent), _repo(QUrl(QString(OSLIST_URL))), _dlnow(0), _verifynow(0),
       _engine(nullptr), _thread(nullptr), _verifyEnabled(false), _cachingEnabled(false),
@@ -274,7 +277,7 @@ void ImageWriter::startWrite()
     {
         _thread = new LocalFileExtractThread(urlstr, _dst.toLatin1(), _expectedHash, this);
     }
-    else if (compressed)
+    else
     {
         _thread = new DownloadExtractThread(urlstr, _dst.toLatin1(), _expectedHash, this);
         if (_repo.toString() == OSLIST_URL)
@@ -284,11 +287,6 @@ void ImageWriter::startWrite()
             tele->start();
         }
     }
-    else
-    {
-        _thread = new DownloadThread(urlstr, _dst.toLatin1(), _expectedHash, this);
-        _thread->setInputBufferSize(IMAGEWRITER_UNCOMPRESSED_BLOCKSIZE);
-    }
 
     connect(_thread, SIGNAL(success()), SLOT(onSuccess()));
     connect(_thread, SIGNAL(error(QString)), SLOT(onError(QString)));
@@ -577,7 +575,7 @@ void ImageWriter::openFileDialog()
 
     QFileDialog *fd = new QFileDialog(nullptr, tr("Select image"),
                                       path,
-                                      "Image files (*.img *.zip *.iso *.gz *.xz *.zst);;All files (*.*)");
+                                      "Image files (*.img *.zip *.iso *.gz *.xz *.zst);;All files (*)");
     connect(fd, SIGNAL(fileSelected(QString)), SLOT(onFileSelected(QString)));
 
     if (_engine)
@@ -992,11 +990,16 @@ QString ImageWriter::getPSK(const QString &ssid)
     }
 
     return psk;
+#else
+#ifndef QT_NO_DBUS
+    NetworkManagerApi nm;
+    return nm.getPSK();
 #else
     Q_UNUSED(ssid)
     return QString();
 #endif
 #endif
+#endif
 }
 
 bool ImageWriter::getBoolSetting(const QString &key)
@@ -1049,18 +1052,7 @@ QString ImageWriter::crypt(const QByteArray &password)
 
 QString ImageWriter::pbkdf2(const QByteArray &psk, const QByteArray &ssid)
 {
-    /* Qt has support for calculating Pbkdf2 starting from Qt 5.12 but
-     * older Linux distributions may not have that.
-     * We can use OpenSSL instead on platforms that have that.
-     * But Mac OS X lacks that, so do use Qt there */
-
-#ifdef Q_OS_DARWIN
     return QPasswordDigestor::deriveKeyPbkdf2(QCryptographicHash::Sha1, psk, ssid, 4096, 32).toHex();
-#else
-    QByteArray digest(32, 0);
-    PKCS5_PBKDF2_HMAC_SHA1(psk.constData(), psk.length(), (const unsigned char*) ssid.constData(), ssid.length(), 4096, digest.length(), (unsigned char *) digest.data());
-    return digest.toHex();
-#endif
 }
 
 void ImageWriter::setSavedCustomizationSettings(const QVariantMap &map)
